@@ -10,21 +10,17 @@ logger = logging.getLogger(__name__)
 
 def import_task(module_name, class_name, function_name, path=None):
     """Find and return the function for given function name."""
-    namespace = import_task_module(module_name, path)
+    namespace = import_module(module_name, path)
     if class_name:
         cls = getattr(namespace, class_name)
         namespace = cls
-    else:
-        cls = None
 
-    task = getattr(namespace, function_name)
-    ImportResult = namedtuple('ImportResult', ['task', 'cls'])
-    return ImportResult(task=task, cls=cls)
+    return getattr(namespace, function_name)
 
 
-def import_task_module(module_name, path=None):
+def import_module(module_name, path=None):
     """Import module by searching main module, current working directory and
-    python path.
+    Python path.
 
     """
     logger.debug("Importing module %r" % module_name)
@@ -39,6 +35,12 @@ def import_task_module(module_name, path=None):
         return importlib.import_module(module_name)
 
 
+def import_class_str(s):
+    module, cls = s.rsplit('.', 1)
+    module = import_module(module)
+    return getattr(module, cls)
+
+
 @contextmanager
 def custom_path(path):
     if path in sys.path:
@@ -52,7 +54,7 @@ def custom_path(path):
 
 
 def get_main_module():
-    """:return main module and module name pair"""
+    """Returns main module and module name pair."""
     main_module = sys.modules['__main__']
     if not hasattr(main_module, '__file__'):
         # if run from interactive shell
